@@ -31,6 +31,9 @@
 
 #include <iosfwd>
 #include <string>
+#ifdef XAPIAN_MOVE_SEMANTICS
+# include <utility>
+#endif
 #include <vector>
 
 #include <xapian/attributes.h>
@@ -136,6 +139,14 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 */
 	void operator=(const Database &other);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+	/// Move constructor.
+	Database(Database&& o);
+
+	/// Move assignment operator.
+	Database& operator=(Database&& o);
+#endif
+
 	/** Re-open the database.
 	 *
 	 *  This re-opens the database(s) to the latest available version(s).
@@ -259,6 +270,12 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	/// Get the average length of the documents in the database.
 	Xapian::doclength get_avlength() const;
 
+	/** Get the total length of all the documents in the database.
+	 *
+	 *  Added in Xapian 1.4.5.
+	 */
+	Xapian::totallength get_total_length() const;
+
 	/// Get the number of documents in the database indexed by a given term.
 	Xapian::doccount get_termfreq(const std::string & tname) const;
 
@@ -289,9 +306,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  stored in the slot.
 	 *
 	 *  @param slot The value slot to examine.
-	 *
-	 *  @exception UnimplementedError The frequency of the value isn't
-	 *  available for this database type.
 	 */
 	Xapian::doccount get_value_freq(Xapian::valueno slot) const;
 
@@ -300,9 +314,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  If there are no values stored in the given value slot, this will
 	 *  return an empty string.
 	 *
-	 *  If the lower bound isn't available for the given database type,
-	 *  this will return the lowest possible bound - the empty string.
-	 *
 	 *  @param slot The value slot to examine.
 	 */
 	std::string get_value_lower_bound(Xapian::valueno slot) const;
@@ -313,9 +324,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  return an empty string.
 	 *
 	 *  @param slot The value slot to examine.
-	 *
-	 *  @exception UnimplementedError The upper bound of the values isn't
-	 *  available for this database type.
 	 */
 	std::string get_value_upper_bound(Xapian::valueno slot) const;
 
@@ -846,6 +854,17 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 */
 	void operator=(const WritableDatabase &other);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+	/// Move constructor.
+	WritableDatabase(WritableDatabase&& o) : Database(std::move(o)) {}
+
+	/// Move assignment operator.
+	WritableDatabase& operator=(WritableDatabase&& o) {
+	    Database::operator=(std::move(o));
+	    return *this;
+	}
+#endif
+
 	/** Commit any pending modifications made to the database.
 	 *
 	 *  For efficiency reasons, when performing multiple updates to a
